#
# Set SULOGIN to yes if you want a sulogin to be spawned from
# this script *before anything else* with a timeout, like on SCO.
#
[ "$SULOGIN" = yes ] && sulogin -t 30 $CONSOLE

#
# Activate the swap device(s) in /etc/fstab. This needs to be done
# before fsck, since fsck can be quite memory-hungry.
#
if [ -x /sbin/swapon ]
then
  [ "$VERBOSE" != no ] && echo "Activating swap..."
  swapon -a 2>/dev/null
fi

#
# Ensure that bdflush (update) is running before any major I/O is
# performed (the following fsck is a good example of such activity :).
#
[ -x /sbin/update ] && update

# Mount proc
# Do this now so fsck can tell what's mounted
# (/etc/mtab -> /proc/mounts)

mount -t proc /proc /proc

# fsck.ext2 here if we want...dangerous if mounted r/w, though...
echo "Checking root filesystems."
if grep -q "22 ide1" /proc/devices; then
	/sbin/fsck.ext2 /dev/hdc1
elif grep -q "100 doc" /proc/devices; then
	/sbin/fsck.ext2 /dev/doc1
elif grep -q "100 fl" /proc/devices; then
	/sbin/fsck.ext2 /dev/doc1
fi

# Remount root filesystem read-write, if desired
if [ -f /etc/READONLY ]
then
	export RO=1
	echo "Preparing to mount root file system READ-ONLY."
	# Prompt for emergency R/W, timeout
	echo -n "Press W to override..."
	sleep 5 && kill -TERM $(/bin/pidof getkey) &
	/bin/getkey w && export RO=0
	echo ""

	if [ "${RO}" = "0" ]
	then
		# Remount read-write...
		echo "READ-ONLY overridden, mounting root filesystem READ-WRITE."
		mount -n -o remount,rw /dev/diskroot /
	else
		echo "Root filesystem mounted READ-ONLY."
	fi

else
	
	echo "Mouting root filesystem READ-WRITE."
	mount -n -o remount,rw /dev/diskroot /

fi


# clear mtab...don't, due to read-only option
# >/etc/mtab

# add entry for root into mtab, don't due to read-only option
# mount -f /dev/hdc2	/

# Mount /dev/ in a ramdisk, do the devices can be read-write
if [ -f /etc/READONLY -a "${RO}" = "1" ]
then
	echo "Creating /dev ramdisk..."
	/sbin/mkfs.minix /dev/ram1
	mount -n -t minix /dev/ram1 /mnt
	cp -a /dev/* /mnt/
	rm -rf /mnt/lost+found
	umount /mnt
	mount -t minix /dev/ram1 /dev
fi

# Mount /var in a ramdisk, to minimize flash writes
echo "Creating /var ramdisk..."
rm -rf /var/*
/sbin/mkfs.minix /dev/ram0
mount -n -t minix /dev/ram0 /var
rm -rf /var/lost+found
mkdir /var/tmp
chmod 777 /var/tmp
mkdir /var/pump
mkdir /var/lib
mkdir /var/run
mkdir /var/log
mkdir /var/spool
mkdir /var/lock
chmod 755 /var/lock
cp /root/resolv.conf /var/pump
cp /root/random-seed /var/lib/
cp /root/random-seed /var/run/
/etc/init.d/make_varfs.sh
