#!/bin/sh

# Some quick bourne shell basics for you novices -
#
# Everything after a hash mark (#) on the same line, is a comment and is ignored
#
# You can seperate commands with a semi-colon (;) instead of a new line
#
# Set a variable like this: VAR="hello"
# Access a variable like this: echo $VAR
#
# A backslash(s) (\) followed by a newline(s) (return) is used as one full line
# echo \
# "hel\
# lo"
# is treated as: 
# echo "hello"
#
# This: [ "$VAR" ] && 
# Means: test ( [ ] ) this variable ($VAR). If it is true ( && ) do this.
# This: [ ! "$VAR" ] &&
# Means: test false ( [!] ) this variable ($VAR). If it is true ( && ) do this.
# This: command && 
# Means: if command exited without errors (true) do this. 
#
# These can be chained for sequential truth. (&& == boolean AND)


###############################################################################
#         All network and routing settings are placed in this file            #
###############################################################################

sleep 1
echo -n "Starting network: "

/etc/sysconfig/ethcfg.sh
/etc/sysconfig/serialcfg.sh
/etc/sysconfig/pppcfg.sh
/etc/sysconfig/setroutes.sh

#Uncomment and a default route will be added. (done in above scripts)
#GATEWAY=208.248.202.65

#ent an interface, and an ifconfig will be performed, and the net added.
#Change the interface name if needed (ethX, wanX, fddiX, etc)

#IF0=eth0
IPADDR0=208.248.202.77 ;	NETMASK0=255.255.255.192
BROADCAST0=208.248.202.127 ;	NETWORK0=208.248.202.0

#IF1=eth1
IPADDR1=192.168.2.1 ;		NETMASK1=255.255.255.0
BROADCAST1=192.168.2.255 ;	NETWORK1=192.168.2.0

#IF2=wan0
IPADDR2=192.168.3.1 ;		NETMASK2=255.255.255.0
BROADCAST2=192.168.3.255 ;	NETWORK2=192.168.3.0

#IF3=fddi0
IPADDR3=192.168.4.1 ;		NETMASK3=255.255.255.0
BROADCAST3=192.168.4.255 ;	NETWORK3=192.168.4.0


###############################################################################
#localhost interface configuration - always needed, don't touch!
###############################################################################
echo 
echo "Configuring loopback device..."
ifconfig lo 127.0.0.1 && echo -n "lo "                                        #
# route add -net 127.0.0.0                                                      # 
###############################################################################


###############################################################################
#Interface configuration - You probably don't need to change this.
###############################################################################

[ "$IF0" ] && \
ifconfig $IF0 $IPADDR0 netmask $NETMASK0 broadcast $BROADCAST0 \
&& echo -n "$IF0 "
[ "$IF1" ] && \
ifconfig $IF1 $IPADDR1 netmask $NETMASK1 broadcast $BROADCAST1 \
&& echo -n "$IF1 "
[ "$IF2" ] && \
ifconfig $IF2 $IPADDR2 netmask $NETMASK2 broadcast $BROADCAST2 \
&& echo -n "$IF2 "
[ "$IF3" ] && \
ifconfig $IF3 $IPADDR1 netmask $NETMASK3 broadcast $BROADCAST3 \
&& echo -n "$IF3 "

echo

###############################################################################
# Static Network Routes - Add or modify as needed.
###############################################################################

#[ "$IF0" ] && route add -net $NETWORK0
#[ "$IF1" ] && route add -net $NETWORK1
#[ "$IF2" ] && route add -net $NETWORK2
#[ "$IF3" ] && route add -net $NETWORK3

# needed for some odd reason...
# [ "$IF0" ] && route add -net 0.0.0.0 netmask 0.0.0.0 dev eth0


###############################################################################
# Static Host Routes - Add or modify as needed
###############################################################################

#[ "$IF1" ] && route add -host 208.192.5.1 gw $IPADDR1 metric 1
# route add -host 208.248.202.65 dev eth0

###############################################################################
# Default Route - You probably don't need to change this.
###############################################################################

[ "$GATEWAY" ] && route add default gw $GATEWAY metric 1

############################################################################
# Unless you've installed firewalling, there are no more executed
# commands below this line.
##############################################################################


###############################################################################
# Place firewall commands, etc down here. Don't run daemons like routed.      #
# Those are run from /etc/init.d/netstd_init                                  # 
# Also make sure to check out /etc/init.d/netbase (inetd, portmap)            #
###############################################################################


###############################################################################
# Firewall rules
###############################################################################

#Flush all Forward, Input, Output, and Accting rules
# ipfwadm -F -f; ipfwadm -I -f; ipfwadm -O -f; ipfwadm -A -f


#Deny all forwarding - for direct unfirewalled routing comment this out
# ipfwadm -F -p deny


###############################################################################
# IP Masquerade (aka NAT)
###############################################################################

#Typical settings
#[ "$IF1" ] && ipfwadm -F -a m -S "$NETWORK1"/24 -D 0.0.0.0/0
#[ "$IF2" ] && ipfwadm -F -a m -S "$NETWORK2"/24 -D 0.0.0.0/0
#[ "$IF3" ] && ipfwadm -F -a m -S "$NETWORK3"/24 -D 0.0.0.0/0


###############################################################################
# IP Redirection
###############################################################################

#This example will forward any Quake connections to an IP Masq'ed machine 
#ipautofw -A -r tcp 26000 26999 -h 192.168.5.80
#ipautofw -A -r udp 26000 26999 -h 192.168.5.80 


###############################################################################
# IP Spoof protection
###############################################################################

# echo -n "Setting up IP spoofing protection: "

# echo -n "127.0.0.0/8 "
# [ "$IF0" ] && ipfwadm -I -i deny -o -P all -S 127.0.0.0/8 -W $IF0 -D 0/0
# [ "$IF1" ] && ipfwadm -I -i deny -o -P all -S 127.0.0.0/8 -W $IF1 -D 0/0
# [ "$IF2" ] && ipfwadm -I -i deny -o -P all -S 127.0.0.0/8 -W $IF2 -D 0/0
# [ "$IF3" ] && ipfwadm -I -i deny -o -P all -S 127.0.0.0/8 -W $IF3 -D 0/0

#You may wish to make these more extensive, or comment some out  
# [ "$IF0" ] && ipfwadm -I -i deny -o -P all -S $IPADDR0 -W $IF0 -D 0/0 \
# && echo -n "$IPADDR0 "
# [ "$IF1" ] && ipfwadm -I -i deny -o -P all -S $IPADDR1 -W $IF1 -D 0/0 \
# && echo -n "$IPADDR1 "
# [ "$IF2" ] && ipfwadm -I -i deny -o -P all -S $IPADDR2 -W $IF2 -D 0/0 \
# && echo -n "$IPADDR2 "
# [ "$IF3" ] && ipfwadm -I -i deny -o -P all -S $IPADDR3 -W $IF3 -D 0/0 \
# && echo -n "$IPADDR3 "
# echo

###############################################################################
#                    Additional Commands - Have fun!
###############################################################################

#arp -i eth0 -Ds ip1 eth0 pub

